@@ -39,7 +39,7 @@ class MondayClient:
         self.notifications = NotificationResource(token=token)
         self.base = BaseResource(api_key=token)
         self.webhooks = WebhooksResource(token=token)
-        self.account = AccountResource
+        self.account = AccountResource(token = token)
 
     def __str__(self):
         return f'MondayClient {__version__}'
