@@ -3,6 +3,12 @@ import time
 import requests
 import json
 
+import backoff
+
+
+def fatal_code(e) -> bool:
+    return 400 <= e.response.status_code < 500
+
 
 class GraphQLClient:
     def __init__(self, endpoint):
@@ -24,7 +30,7 @@ class GraphQLClient:
         """
         r = self._send(query_with_complexity, variables)
         if 'errors' in r:
-            raise Exception(', '.join([e['message'] if 'message' in e else str(e) for e in r['errors']]))
+            raise requests.HTTPError(', '.join([e['message'] if 'message' in e else str(e) for e in r['errors']]))
 
         # rate limiting
         complexity = r['data']['complexity']
@@ -32,15 +38,22 @@ class GraphQLClient:
             time.sleep(complexity['reset_in_x_seconds'] + 1)
             r = self._send(query_with_complexity, variables)
             complexity = r['data']['complexity']
-        if r.status_code >= 400:
-            raise Exception(r.text)
         if 'errors' in r:
-            raise Exception(', '.join([e['message'] if 'message' in e else str(e) for e in r['errors']]))
+            raise requests.HTTPError(', '.join([e['message'] if 'message' in e else str(e) for e in r['errors']]))
+        return r['data']
 
     def inject_token(self, token, header_name='Authorization'):
         self.token = token
         self.header_name = header_name
 
+    # noinspection PyTypeChecker
+    @backoff.on_exception(
+        backoff.expo,
+        requests.exceptions.RequestException,
+        max_tries = 8,
+        raise_on_giveup = True,
+        giveup = fatal_code
+    )
     def _send(self, query, variables):
         payload = {'query': query}
         headers = {}
@@ -64,4 +77,5 @@ class GraphQLClient:
             return response.json()
         except requests.HTTPError as e:
             print(e)
+            print(f"Original payload: {payload}")
             raise e
