@@ -1,5 +1,10 @@
+from monday.query_joins import (
+    get_account_query,
+    get_app_subscription_query,
+    get_apps_monetization_supported_query,
+    get_self_query,
+)
 from monday.resources.base import BaseResource
-from monday.query_joins import get_apps_monetization_supported_query, get_app_subscription_query, get_account_query, get_self_query
 
 
 class AccountResource(BaseResource):
